searchData={"items":[{"type":"task","title":"mix usage_rules.install","doc":"Installs usage_rules","ref":"Mix.Tasks.UsageRules.Install.html"},{"type":"task","title":"Example - mix usage_rules.install","doc":"```sh\nmix igniter.install usage_rules\n```","ref":"Mix.Tasks.UsageRules.Install.html#module-example"},{"type":"task","title":"mix usage_rules.sync","doc":"Combine the package rules for the provided packages into the provided file, or list/gather all dependencies.","ref":"Mix.Tasks.UsageRules.Sync.html"},{"type":"task","title":"Options - mix usage_rules.sync","doc":"* `--all` - Gather usage rules from all dependencies that have them\n* `--list` - List all dependencies with usage rules. If a file is provided, shows status (present, missing, stale)\n* `--remove` - Remove specified packages from the target file instead of adding them\n* `--link-to-folder  ` - Save usage rules for each package in separate files within the specified folder and create CLAUDE.md style links","ref":"Mix.Tasks.UsageRules.Sync.html#module-options"},{"type":"task","title":"Examples - mix usage_rules.sync","doc":"Combine specific packages:\n```sh\nmix usage_rules.sync rules.md ash ash_postgres phoenix\n```\n\nGather all dependencies with usage rules:\n```sh\nmix usage_rules.sync rules.md --all\n```\n\nList all dependencies with usage rules:\n```sh\nmix usage_rules.sync --list\n```\n\nCheck status of dependencies against a specific file:\n```sh\nmix usage_rules.sync rules.md --list\n```\n\nRemove specific packages from a file:\n```sh\nmix usage_rules.sync rules.md ash phoenix --remove\n```\n\nSave usage rules to individual files in a folder with links to individual files:\n```sh\nmix usage_rules.sync rules.md ash phoenix --link-to-folder rules\n```\n\nCombine all dependencies with folder links with links to individual files:\n```sh\nmix usage_rules.sync rules.md --all --link-to-folder docs\n```\n\nCheck status of packages using folder links:\n```sh\nmix usage_rules.sync rules.md --list --link-to-folder rules\n```\n\nRemove packages and their folder files:\n```sh\nmix usage_rules.sync rules.md ash phoenix --remove --link-to-folder rules\n```","ref":"Mix.Tasks.UsageRules.Sync.html#module-examples"},{"type":"module","title":"UsageRules","doc":"Tools for gathering usage rules from dependencies for projects.","ref":"UsageRules.html"},{"type":"extras","title":"Home","doc":"# UsageRules\n\n**UsageRules** is a development tool for Elixir projects that helps gather and consolidate usage rules from dependencies. The package provides Mix tasks to collect documentation from dependencies that have `usage-rules.md` files and combine them into a single rules file for your project.\n\nYou'll note this package itself doesn't have a usage-rules.md. Its a simple tool that likely would not benefit from having a usage-rules.md file.\n\n`usage-rules.md` is not an existing standard, rather it is a community initiative that may evolve over time as adoption grows and feedback is gathered. We encourage experimentation and welcome input on how to make this approach more useful for the broader Elixir ecosystem.","ref":"readme.html"},{"type":"extras","title":"For Package Authors - Home","doc":"Even if you don't want to use LLMs, its very possible that your users will, and they will often come to you with hallucinations from their LLMs and try to get your help with it. Writing a `usage-rules.md` file is a great way to stop this sort of thing 😁\n\nWe don't really know what makes great usage-rules.md files yet. Ash Framework is experimenting with quite fleshed out usage rules which seems to be working quite well. See [Ash Framework's usage-rules.md](https://github.com/ash-project/ash/blob/main/usage-rules.md) for one such large example. Perhaps for your package or framework only a few lines are necessary. We will all have to adjust over time.\n\nOne quick tip is to have an agent begin the work of writing rules for you, by pointing it at your docs and asking it to write a `usage-rules.md` file in a condensed format that would be useful for agents to work with your tool. Then, aggressively prune and edit it to your taste.","ref":"readme.html#for-package-authors"},{"type":"extras","title":"Key Features - Home","doc":"1. **Dependency Rules Collection**: Automatically discovers and collects usage rules from dependencies that provide `usage-rules.md` files in their package directory\n2. **Rules Consolidation**: Combines multiple package rules into a single file with proper sectioning and markers\n3. **Status Tracking**: Can list dependencies with usage rules and check if your consolidated file is up-to-date\n4. **Selective Management**: Allows adding/removing specific packages from your rules file","ref":"readme.html#key-features"},{"type":"extras","title":"How It Works - Home","doc":"1. The tool scans your project's dependencies (in `deps/` directory)\n2. Looks for `usage-rules.md` files in each dependency\n3. Consolidates these rules into a target file with special markers like `<-- package-name-start -->` and `<-- package-name-end -->`\n4. Maintains sections that can be updated independently as dependencies change\n\nThis is particularly useful for projects using frameworks like Ash, Phoenix, or other packages that provide specific usage guidelines, coding patterns, or best practices that should be followed consistently across your project.","ref":"readme.html#how-it-works"},{"type":"extras","title":"Usage - Home","doc":"The main task `Mix.Tasks.UsageRules.Sync` provides several modes of operation:","ref":"readme.html#usage"},{"type":"extras","title":"Combine specific packages - Home","doc":"```sh\nmix usage_rules.sync rules.md ash phoenix\n```","ref":"readme.html#combine-specific-packages"},{"type":"extras","title":"Gather all dependencies with usage rules - Home","doc":"```sh\nmix usage_rules.sync rules.md --all\n```","ref":"readme.html#gather-all-dependencies-with-usage-rules"},{"type":"extras","title":"List available packages with usage rules - Home","doc":"```sh\nmix usage_rules.sync --list\n```","ref":"readme.html#list-available-packages-with-usage-rules"},{"type":"extras","title":"Check status against a file - Home","doc":"```sh\nmix usage_rules.sync rules.md --list\n```","ref":"readme.html#check-status-against-a-file"},{"type":"extras","title":"Remove packages from a file - Home","doc":"```sh\nmix usage_rules.sync rules.md ash --remove\n```","ref":"readme.html#remove-packages-from-a-file"},{"type":"extras","title":"Installation - Home","doc":"","ref":"readme.html#installation"},{"type":"extras","title":"With Igniter - Home","doc":"`mix igniter.install usage_rules`.\n\nAdd the dependency manually\n\n```elixir\ndef deps do\n  [\n    # should only ever be used as a dev dependency\n    # requires igniter as a dev dependency\n    {:usage_rules, \"~> 0.1\", only: [:dev]},\n    {:igniter, \"~> 0.6\", only: [:dev]}\n  ]\nend\n```","ref":"readme.html#with-igniter"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}